==> ask-jennie-0.0.3.tar.gz: ask-jennie-0.0.3/jennie/protocols/ubuntu/__init__.py <==
from jennie.protocols.ubuntu.deployfrontend import deploy_folder_nginx
from jennie.protocols.ubuntu.deploybackend import deploy_django
from jennie.protocols.ubuntu.setuplemp import setup_lemp
from jennie.protocols.ubuntu.setupelasticsearchkibana import setup_elasticsearchkibana
from jennie.protocols.ubuntu.setupphpmyadmin import install_phpmyadmin
from jennie.protocols.ubuntu.setupelasticsearch import setup_elasticsearch
from jennie.utils.helper import take_user_input

DEPLOY_INFO_COMMANDS = {
    "port": "Input port no to which the project has to be deployed",
    "domain": "Input your domain name, can add IP address as domain name"
}

class UbuntuAutomation():
    def execute(self, args):
        if args[1] == "setup" and args[2] == "elk":
            return setup_elasticsearchkibana()

        elif args[1] == "setup" and args[2] == "elasticsearch":
            return setup_elasticsearch()

        elif args[1] == "setup" and args[2] == "lemp":
            return setup_lemp()

        elif args[1] == "setup" and args[2] == "phpmyadmin":
            return install_phpmyadmin()

        elif args[1] == "deploy" and args[2] == "web":
            UbuntuDeployAutomations().web()

        elif args[1] == "deploy" and args[2] == "django-automations":
            UbuntuDeployAutomations().django()

class UbuntuDeployAutomations():
    def __init__(self):
        self.info = take_user_input(DEPLOY_INFO_COMMANDS)

    def web(self):
        deploy_folder_nginx(self.info["port"], self.info["domain"])

    def django(self):
        deploy_django(self.info["port"], self.info["domain"])

==> ask-jennie-0.0.10.tar.gz: ask-jennie-0.0.10/jennie/protocols/ubuntu/__init__.py <==
from jennie.protocols.ubuntu.deployfrontend import deploy_folder_nginx
from jennie.protocols.ubuntu.deploybackend import deploy_django
from jennie.protocols.ubuntu.setuplemp import setup_lemp
from jennie.protocols.ubuntu.setupelasticsearchkibana import setup_elasticsearchkibana
from jennie.protocols.ubuntu.setupphpmyadmin import install_phpmyadmin
from jennie.protocols.ubuntu.setupelasticsearch import setup_elasticsearch
from jennie.utils.helper import take_user_input

DEPLOY_INFO_COMMANDS = {
    "port": "Input port no to which the project has to be deployed",
    "domain": "Input your domain name, can add IP address as domain name"
}

class UbuntuAutomation():
    def execute(self, args):
        if args[1] == "setup" and args[2] == "elk":
            return setup_elasticsearchkibana()

        elif args[1] == "setup" and args[2] == "elasticsearch":
            return setup_elasticsearch()

        elif args[1] == "setup" and args[2] == "lemp":
            return setup_lemp()

        elif args[1] == "setup" and args[2] == "phpmyadmin":
            return install_phpmyadmin()

        elif args[1] == "deploy" and args[2] == "web":
            UbuntuDeployAutomations().web()

        elif args[1] == "deploy" and args[2] == "django":
            UbuntuDeployAutomations().django()

class UbuntuDeployAutomations():
    def __init__(self):
        self.info = take_user_input(DEPLOY_INFO_COMMANDS)

    def web(self):
        deploy_folder_nginx(self.info["port"], self.info["domain"])

    def django(self):
        deploy_django(self.info["port"], self.info["domain"])
